@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-11-30 16:28:21
-# @Last Modified time: 2021-12-30 19:18:03
+# @Last Modified time: 2021-12-30 19:45:56
 # @github: https://github.com/longfengpili
 
 # !/usr/bin/env python3
@@ -53,10 +53,8 @@ class ColumnsModel(object):
     def __repr__(self):
         return f"{[column for column in self.columns]}"
 
-    def __getitem__(self, name):
-        for col in self.columns:
-            if col.newname == name:
-                return col
+    def __getitem__(self, key):
+        return self.columns[key]
 
     def index(self, key):
         return self.columns[key]
